-- DATEV SKR03
--
INSERT INTO gifi (accno,description) VALUES ('0000100', 'Aufwand Geschftsbetrieb');
INSERT INTO gifi (accno,description) VALUES ('0000200', 'Aufwendungen Umstellung a.d.Euro');
INSERT INTO gifi (accno,description) VALUES ('0001000', 'Konzession,gewerb.Schutzre.u.Werten');
INSERT INTO gifi (accno,description) VALUES ('0001500', 'Konzessionen');
INSERT INTO gifi (accno,description) VALUES ('0002700', 'EDV-Software');
INSERT INTO gifi (accno,description) VALUES ('0003500', 'Geschfts-oder Firmenwert');
INSERT INTO gifi (accno,description) VALUES ('0003800', 'Anzahlungen a.Geschft-o.Firmenwert');
INSERT INTO gifi (accno,description) VALUES ('0003900', 'Anz.a.immaterielle Vermgsgegenstn');
INSERT INTO gifi (accno,description) VALUES ('0004000', 'Verschmelzungsmehrwert');
INSERT INTO gifi (accno,description) VALUES ('0005000', 'Grundstcke,grundstcksgl.Rechte..');
INSERT INTO gifi (accno,description) VALUES ('0006000', 'Grundstcke u.grundstgl.Rech.o.Baut');
INSERT INTO gifi (accno,description) VALUES ('0008000', 'Bauten a.eig. Grundstcken,Grgl.Rec');
INSERT INTO gifi (accno,description) VALUES ('0008500', 'Grundstckswert eige.bebau.Grundst.');
INSERT INTO gifi (accno,description) VALUES ('0009000', 'Geschftsbauten');
INSERT INTO gifi (accno,description) VALUES ('0010000', 'Fabrikbauten');
INSERT INTO gifi (accno,description) VALUES ('0011000', 'Garagen');
INSERT INTO gifi (accno,description) VALUES ('0011100', 'Auenanlagen');
INSERT INTO gifi (accno,description) VALUES ('0011200', 'Hof-und Wegebefestigung');
INSERT INTO gifi (accno,description) VALUES ('0011500', 'Andere Bauten');
INSERT INTO gifi (accno,description) VALUES ('0012000', 'Geschfts-,Fabrik-,andere Bau.imBau');
INSERT INTO gifi (accno,description) VALUES ('0012900', 'Anz.Geschfts-,Fabrik u. and.Bauten');
INSERT INTO gifi (accno,description) VALUES ('0015000', 'Wohnbauten im Bau');
INSERT INTO gifi (accno,description) VALUES ('0016000', 'Bauten auf fremden Grundstcken');
INSERT INTO gifi (accno,description) VALUES ('0016500', 'Geschftsbauten');
INSERT INTO gifi (accno,description) VALUES ('0017000', 'Fabrikbauten');
INSERT INTO gifi (accno,description) VALUES ('0017500', 'Garagen');
INSERT INTO gifi (accno,description) VALUES ('0017600', 'Auenanlage');
INSERT INTO gifi (accno,description) VALUES ('0020000', 'Techn.Anlagen und Maschinen');
INSERT INTO gifi (accno,description) VALUES ('0021000', 'Maschinen');
INSERT INTO gifi (accno,description) VALUES ('0022000', 'Maschinengebundene Werkzeuge');
INSERT INTO gifi (accno,description) VALUES ('0024000', 'Maschinelle Anlagen');
INSERT INTO gifi (accno,description) VALUES ('0028000', 'Betriebsvorrichtung');
INSERT INTO gifi (accno,description) VALUES ('0029000', 'Techn.Anlagen u.Maschinen im Bau');
INSERT INTO gifi (accno,description) VALUES ('0029900', 'Anz.a.techn.Anlagen und Maschinen');
INSERT INTO gifi (accno,description) VALUES ('0030000', 'Andere Anlagen,Betrieb-Geschftsaus');
INSERT INTO gifi (accno,description) VALUES ('0031000', 'Andere Anlagen');
INSERT INTO gifi (accno,description) VALUES ('0032000', 'PKW');
INSERT INTO gifi (accno,description) VALUES ('0035000', 'LKW');
INSERT INTO gifi (accno,description) VALUES ('0040000', 'Betriebsausstattung');
INSERT INTO gifi (accno,description) VALUES ('0041000', 'Geschftsausstattung');
INSERT INTO gifi (accno,description) VALUES ('0042000', 'Broeinrichtung');
INSERT INTO gifi (accno,description) VALUES ('0043000', 'Ladeneinrichtung');
INSERT INTO gifi (accno,description) VALUES ('0048000', 'Geringwertige Wirtschaftsg.b.800DM');
INSERT INTO gifi (accno,description) VALUES ('0049000', 'Sons.Betriebs- Geschftsausstattung');
INSERT INTO gifi (accno,description) VALUES ('0049800', 'And. Anlagen,Betrieb/Geschf.im Bau');
INSERT INTO gifi (accno,description) VALUES ('0049900', 'Anz.and.Anlagen,Betrieb.Geschftsau');
INSERT INTO gifi (accno,description) VALUES ('0050000', 'Anteile a.verb.Unternehmen');
INSERT INTO gifi (accno,description) VALUES ('0050400', 'Ant.a.herr.o.m.Mehrh.bet.Ges.schaft');
INSERT INTO gifi (accno,description) VALUES ('0050500', 'Ausleihung an verb.Unternehmen');
INSERT INTO gifi (accno,description) VALUES ('0051000', 'Beteiligungen');
INSERT INTO gifi (accno,description) VALUES ('0051300', 'Typisch stille Beteiligungen');
INSERT INTO gifi (accno,description) VALUES ('0051600', 'Atypische stille Beteiligungen');
INSERT INTO gifi (accno,description) VALUES ('0052000', 'Ausl.a.Untern.m.Beteiligungsverhlt');
INSERT INTO gifi (accno,description) VALUES ('0052500', 'Wertpapiere des Anlagevermgens');
INSERT INTO gifi (accno,description) VALUES ('0054000', 'Sonstige Ausleihungen');
INSERT INTO gifi (accno,description) VALUES ('0057000', 'Genossenschaftsan.z.langf.Verbleib');
INSERT INTO gifi (accno,description) VALUES ('0059500', 'Rckdeckansp.Lebensvers.langf.Verbl');
INSERT INTO gifi (accno,description) VALUES ('0060000', 'Anleihen-nicht konvertibel');
INSERT INTO gifi (accno,description) VALUES ('0063000', 'Verbindl.gegenber Kreditinstituten');
INSERT INTO gifi (accno,description) VALUES ('0070000', 'Verbind.gegenber verb.Unternehmern');
INSERT INTO gifi (accno,description) VALUES ('0071500', 'Verbind.gegen.Untern.m.Beteili.Verh');
INSERT INTO gifi (accno,description) VALUES ('0073000', 'Verbindlichkeiten gegen. Gesellscha');
INSERT INTO gifi (accno,description) VALUES ('0076000', 'Darl.typ.stiller Gesellschafter');
INSERT INTO gifi (accno,description) VALUES ('0078000', 'Partiarische Darlehen');
INSERT INTO gifi (accno,description) VALUES ('0080000', 'Gezeichnetes Kapital');
INSERT INTO gifi (accno,description) VALUES ('0080100', 'Ausst.Einl.a.d.gezeichnete Kapital');
INSERT INTO gifi (accno,description) VALUES ('0084000', 'Kapitalrcklage');
INSERT INTO gifi (accno,description) VALUES ('0084600', 'Gesetzliche Rcklage');
INSERT INTO gifi (accno,description) VALUES ('0085000', 'Rcklage fr eigene Anteile');
INSERT INTO gifi (accno,description) VALUES ('0085100', 'Satzungsmige Rcklagen');
INSERT INTO gifi (accno,description) VALUES ('0086000', 'Gewinnvortrag vor Verwendung');
INSERT INTO gifi (accno,description) VALUES ('0086800', 'Verlustvortrag vor Verwendung');
INSERT INTO gifi (accno,description) VALUES ('0086900', 'Vortrag auf neue Rechnungen');
INSERT INTO gifi (accno,description) VALUES ('0087000', 'Festkapital');
INSERT INTO gifi (accno,description) VALUES ('0088000', 'Variables Kapital');
INSERT INTO gifi (accno,description) VALUES ('0089000', 'Gesellschafter-Darlehen');
INSERT INTO gifi (accno,description) VALUES ('0090000', 'Kommandit-Kapital');
INSERT INTO gifi (accno,description) VALUES ('0091000', 'Verlustausgleichskonto');
INSERT INTO gifi (accno,description) VALUES ('0092000', 'Gesellschafter-Darlehen');
INSERT INTO gifi (accno,description) VALUES ('0093000', 'Sonderposten mit Rcklagenanteil');
INSERT INTO gifi (accno,description) VALUES ('0093100', 'Sopo m.Rckl.ant.nach 6b EstG');
INSERT INTO gifi (accno,description) VALUES ('0093200', 'Sopo m.Rckl.ant.Abschn.35 EstR');
INSERT INTO gifi (accno,description) VALUES ('0093500', 'Sopo aus Whrungsumstellung Euro');
INSERT INTO gifi (accno,description) VALUES ('0094700', 'Sopo m.Rckl.ant. 7g Abs.1 EstG');
INSERT INTO gifi (accno,description) VALUES ('0094800', 'Sopo m.Rckl.ant. 7g Abs.3,7 EstG');
INSERT INTO gifi (accno,description) VALUES ('0095500', 'Steuerrckstellung');
INSERT INTO gifi (accno,description) VALUES ('0095700', 'Gewerbesteuerrckstellung');
INSERT INTO gifi (accno,description) VALUES ('0096300', 'Krperschaftssteuerrckstellung');
INSERT INTO gifi (accno,description) VALUES ('0096900', 'Rckstellung fr latente Steuern');
INSERT INTO gifi (accno,description) VALUES ('0097000', 'Sonstige Rckstellungen');
INSERT INTO gifi (accno,description) VALUES ('0097400', 'Rckstellungen fr Gewhrleistungen');
INSERT INTO gifi (accno,description) VALUES ('0097600', 'Rcks.f.drohe.Verl.schweb.Geschft');
INSERT INTO gifi (accno,description) VALUES ('0097700', 'Rcks.f.Abschlu-u.Prfungskosten');
INSERT INTO gifi (accno,description) VALUES ('0097800', 'Aufwandsrckstellungen');
INSERT INTO gifi (accno,description) VALUES ('0098000', 'Aktive Rechnungsabgrenzung');
INSERT INTO gifi (accno,description) VALUES ('0098300', 'Abgrenzung aktive latente Steuern');
INSERT INTO gifi (accno,description) VALUES ('0098600', 'Damnum/Disagio');
INSERT INTO gifi (accno,description) VALUES ('0099000', 'Passive Rechnungsabgrenzung');
INSERT INTO gifi (accno,description) VALUES ('0099200', 'Wertberichtigungen');
INSERT INTO gifi (accno,description) VALUES ('0099600', 'Pauschalwertb.m.Restlaufzeit v. 1J.');
INSERT INTO gifi (accno,description) VALUES ('0099800', 'Einzelwertber.m.Restlaufzeit v.1 J.');
INSERT INTO gifi (accno,description) VALUES ('0100000', 'Kasse');
INSERT INTO gifi (accno,description) VALUES ('0110000', 'Postbank');
INSERT INTO gifi (accno,description) VALUES ('0120000', 'Bank');
INSERT INTO gifi (accno,description) VALUES ('0121000', 'Dresdner Bank AG');
INSERT INTO gifi (accno,description) VALUES ('0121009', 'Verrechnungskonto Dresdner Bank AG');
INSERT INTO gifi (accno,description) VALUES ('0122000', 'Deutsche Bank AG');
INSERT INTO gifi (accno,description) VALUES ('0130000', 'Wechsel a. Lieferungen u.Leistungen');
INSERT INTO gifi (accno,description) VALUES ('0131000', 'Besitzwechsel geg.verb.Unternehmen');
INSERT INTO gifi (accno,description) VALUES ('0132000', 'Besitzw.geg.Untern.m.Beteiligungsve');
INSERT INTO gifi (accno,description) VALUES ('0132700', 'Finanzwechsel');
INSERT INTO gifi (accno,description) VALUES ('0133000', 'Schecks (Eingang)');
INSERT INTO gifi (accno,description) VALUES ('0133300', 'Schecks (Ausgang)');
INSERT INTO gifi (accno,description) VALUES ('0133500', 'berweisungen (unterwegs)');
INSERT INTO gifi (accno,description) VALUES ('0134000', 'Anteile verb.Untern.-Umlaufvermgen');
INSERT INTO gifi (accno,description) VALUES ('0134400', 'Anteil an herr.m.betei.Gesellschaft');
INSERT INTO gifi (accno,description) VALUES ('0134500', 'Eigene Anteile');
INSERT INTO gifi (accno,description) VALUES ('0134800', 'Sonstige Wertpapiere');
INSERT INTO gifi (accno,description) VALUES ('0136000', 'Geldtransit');
INSERT INTO gifi (accno,description) VALUES ('0136100', 'Geldtransit (berweisungen)');
INSERT INTO gifi (accno,description) VALUES ('0136200', 'Geldtransit,Bankeinzug/Lastschrift');
INSERT INTO gifi (accno,description) VALUES ('0136300', 'Scheck / Wechsel');
INSERT INTO gifi (accno,description) VALUES ('0140000', 'Ford. a.Lieferungen und Leistungen');
INSERT INTO gifi (accno,description) VALUES ('0141100', 'Forderungssammelkonto Vorausre.');
INSERT INTO gifi (accno,description) VALUES ('0141200', 'Forderungssammelkonto Anzahlungen');
INSERT INTO gifi (accno,description) VALUES ('0146000', 'Zweifelhafte Forderungen');
INSERT INTO gifi (accno,description) VALUES ('0147000', 'Forder.a.Liefe.u.Leis.geg.verb.Unte');
INSERT INTO gifi (accno,description) VALUES ('0147800', 'Wertb.a.Ford.m.Rest.1j.geg.verb.Unt');
INSERT INTO gifi (accno,description) VALUES ('0148000', 'Lief.u.Leis.geg.Untern.m.Beteiligve');
INSERT INTO gifi (accno,description) VALUES ('0148800', 'Wertb.a.Ford.m.Rest.1j.Beteiligungs');
INSERT INTO gifi (accno,description) VALUES ('0149000', 'Forderung a.Leis.u.Lief.geg.Gesells');
INSERT INTO gifi (accno,description) VALUES ('0150000', 'Sonstige Vermgensgegenstnde');
INSERT INTO gifi (accno,description) VALUES ('0150300', 'Forde.geg.Vorstandsm.u.Geschftsfh');
INSERT INTO gifi (accno,description) VALUES ('0150800', 'Forderungen gegen Gesellschafter');
INSERT INTO gifi (accno,description) VALUES ('0151000', 'Geleistete Anzahlung auf Vorrte');
INSERT INTO gifi (accno,description) VALUES ('0151100', 'Geleistete Anzahlungen 7%');
INSERT INTO gifi (accno,description) VALUES ('0151700', 'Geleistete Anzahlung 16%');
INSERT INTO gifi (accno,description) VALUES ('0152500', 'Kautionen');
INSERT INTO gifi (accno,description) VALUES ('0153000', 'Forderungen gegen Personal');
INSERT INTO gifi (accno,description) VALUES ('0154000', 'Steuerberzahlungen');
INSERT INTO gifi (accno,description) VALUES ('0154500', 'Umsatzsteuerforderungen');
INSERT INTO gifi (accno,description) VALUES ('0154800', 'Vorsteuer im Folgejahr abziehbar');
INSERT INTO gifi (accno,description) VALUES ('0154900', 'Krperschaftsteuerrckforderung');
INSERT INTO gifi (accno,description) VALUES ('0155000', 'Darlehen');
INSERT INTO gifi (accno,description) VALUES ('0156000', 'Aufzuteilende Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0156500', 'Aufzuteilende Vorsteuer 16%');
INSERT INTO gifi (accno,description) VALUES ('0157000', 'Abziehbare Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0157100', 'Abziebare Vorsteuer 7%');
INSERT INTO gifi (accno,description) VALUES ('0157200', 'Abziehb. VorSt innergemein. Erwerb');
INSERT INTO gifi (accno,description) VALUES ('0157300', 'Abziehb.VorSt. innergem.Erwerb 16%');
INSERT INTO gifi (accno,description) VALUES ('0157500', 'Abziehbare Vorsteuer 16%');
INSERT INTO gifi (accno,description) VALUES ('0157800', 'Berichtigung d.Vorstabzugs frh.J.');
INSERT INTO gifi (accno,description) VALUES ('0157900', 'Vorsteuer 0%');
INSERT INTO gifi (accno,description) VALUES ('0158400', 'abziehb.VorSt IG Erwerb Neufahrzeug');
INSERT INTO gifi (accno,description) VALUES ('0158800', 'Bezahlte Einfuhrumsatzsteuer');
INSERT INTO gifi (accno,description) VALUES ('0159000', 'Durchlaufende Posten');
INSERT INTO gifi (accno,description) VALUES ('0159400', 'Forderungen geg. verb. Unternehmen');
INSERT INTO gifi (accno,description) VALUES ('0159700', 'Ford.geg.Untern.m.Beteiligungsverh.');
INSERT INTO gifi (accno,description) VALUES ('0160000', 'Verbindlichkeiten aus Lief.u.Leist.');
INSERT INTO gifi (accno,description) VALUES ('0160100', 'Verbindlichkeiten a.Lief.und Leist.');
INSERT INTO gifi (accno,description) VALUES ('0163000', 'Verbindl.Lief.u.Leist.geg.verb.Unt');
INSERT INTO gifi (accno,description) VALUES ('0164000', 'Verb.L.u.L geg.Unter.Beteiligungsv');
INSERT INTO gifi (accno,description) VALUES ('0165000', 'Verb.L.u.L geg.Gesellschaftern');
INSERT INTO gifi (accno,description) VALUES ('0166000', 'Schuldwechsel');
INSERT INTO gifi (accno,description) VALUES ('0170000', 'Sonstige Verbindlichkeiten');
INSERT INTO gifi (accno,description) VALUES ('0170500', 'Darlehen');
INSERT INTO gifi (accno,description) VALUES ('0170900', 'Gewinnverfgungskonto stiller Ges.');
INSERT INTO gifi (accno,description) VALUES ('0171000', 'Erhaltene Anzahlungen-Verbindlichke');
INSERT INTO gifi (accno,description) VALUES ('0171100', 'Erhaltene,versteuert Anzahlungen 7%');
INSERT INTO gifi (accno,description) VALUES ('0171700', 'Erhaltene,versteuerte Anzahl. 16%');
INSERT INTO gifi (accno,description) VALUES ('0171900', 'Erhaltene Anzahlungen bis 1j.');
INSERT INTO gifi (accno,description) VALUES ('0172200', 'Erhaltene Anzahlung');
INSERT INTO gifi (accno,description) VALUES ('0172300', 'Verbindlichkeiten S-konto Vorausre.');
INSERT INTO gifi (accno,description) VALUES ('0173200', 'Erhaltene Kautionen');
INSERT INTO gifi (accno,description) VALUES ('0174100', 'Verbindl.a.Lohn-und Kirchensteuer');
INSERT INTO gifi (accno,description) VALUES ('0175500', 'Lohn-und Gehaltsverrechnung');
INSERT INTO gifi (accno,description) VALUES ('0175800', 'USt-Abzugsverfahren 16%');
INSERT INTO gifi (accno,description) VALUES ('0175900', 'Ust 0%');
INSERT INTO gifi (accno,description) VALUES ('0176000', 'Umsatzsteuer nicht fllig');
INSERT INTO gifi (accno,description) VALUES ('0176100', 'Umsatzsteuer nicht fllig 7%');
INSERT INTO gifi (accno,description) VALUES ('0176200', 'Umsatzsteuer nicht fllig EG Lief.');
INSERT INTO gifi (accno,description) VALUES ('0177000', 'Umsatzsteuer');
INSERT INTO gifi (accno,description) VALUES ('0177100', 'Umsatzsteuer 7%');
INSERT INTO gifi (accno,description) VALUES ('0177200', 'Umsatzsteuer aus innergem. Erwerb');
INSERT INTO gifi (accno,description) VALUES ('0177300', 'Umsatzsteuer innergem.Erwerb 16%');
INSERT INTO gifi (accno,description) VALUES ('0177500', 'Umsatzsteuer 16%');
INSERT INTO gifi (accno,description) VALUES ('0177700', 'Ust aus im Inland stpfl. EG-Lief16%');
INSERT INTO gifi (accno,description) VALUES ('0178000', 'Umsatzsteuer-Vorauszahlungen');
INSERT INTO gifi (accno,description) VALUES ('0178100', 'Umsatzsteuer-Vorauszahlung 1/11');
INSERT INTO gifi (accno,description) VALUES ('0178300', 'In Rechn unberecht.ausgew.gesch Ust');
INSERT INTO gifi (accno,description) VALUES ('0178400', 'Ust IG Erwerb Neufahrzeug o.Ust ID');
INSERT INTO gifi (accno,description) VALUES ('0178800', 'Einfuhrumsatzsteuer augeschoben bis');
INSERT INTO gifi (accno,description) VALUES ('0178900', 'Umsatzsteuer laufendes Jahr');
INSERT INTO gifi (accno,description) VALUES ('0179000', 'Umsatzsteuer Vorjahr');
INSERT INTO gifi (accno,description) VALUES ('0179100', 'Umsatzsteuer frhere Jahre');
INSERT INTO gifi (accno,description) VALUES ('0179200', 'Sonstige Verrechnungskonten');
INSERT INTO gifi (accno,description) VALUES ('0180000', 'Privatentnahme allgemein');
INSERT INTO gifi (accno,description) VALUES ('0181000', 'Privatsteuern');
INSERT INTO gifi (accno,description) VALUES ('0189000', 'Privateinlagen');
INSERT INTO gifi (accno,description) VALUES ('0200000', 'Auerordentliche Aufwendung');
INSERT INTO gifi (accno,description) VALUES ('0201000', 'Betriebsfremde Aufwendungen');
INSERT INTO gifi (accno,description) VALUES ('0202000', 'Periodenfremde Aufwendungen');
INSERT INTO gifi (accno,description) VALUES ('0210000', 'Zinsen und hnl.Aufwendungen');
INSERT INTO gifi (accno,description) VALUES ('0210300', 'Steuerl.abzugsfhig,and.Nebenl.Steu');
INSERT INTO gifi (accno,description) VALUES ('0210400', 'Steuerl.nicht.abzugsf.ande.Nl.z.Ste');
INSERT INTO gifi (accno,description) VALUES ('0210700', 'Zinsaufwendung-betriebliche Steuern');
INSERT INTO gifi (accno,description) VALUES ('0210800', 'Zinsaufwendung-Personsteuer');
INSERT INTO gifi (accno,description) VALUES ('0210900', 'Zinsaufwendungen an verb.Unternehm.');
INSERT INTO gifi (accno,description) VALUES ('0211000', 'Zinsaufwendung f.kurzf.Verbindlichk');
INSERT INTO gifi (accno,description) VALUES ('0212000', 'Zinsaufwendung f.langf.Verbindlichk');
INSERT INTO gifi (accno,description) VALUES ('0213000', 'Diskontaufwendung');
INSERT INTO gifi (accno,description) VALUES ('0215000', 'Aufwendungen aus Kursdifferenzen');
INSERT INTO gifi (accno,description) VALUES ('0216500', 'Aufw.a.d.Whrungsumstell.a.d.Euro');
INSERT INTO gifi (accno,description) VALUES ('0217000', 'Nicht abziehbare Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0217100', 'Nicht abziehbare Vorsteuer 7%');
INSERT INTO gifi (accno,description) VALUES ('0217500', 'Nicht abziehbare Vorsteuer 16%');
INSERT INTO gifi (accno,description) VALUES ('0220000', 'Krperschaftssteuer');
INSERT INTO gifi (accno,description) VALUES ('0220300', 'Krperschaftssteuer fr Vorjahr');
INSERT INTO gifi (accno,description) VALUES ('0220500', 'Anrechb.Krperschaftsst.vereinn.Kap');
INSERT INTO gifi (accno,description) VALUES ('0220800', 'Solidarittszuschlag');
INSERT INTO gifi (accno,description) VALUES ('0220900', 'Solidarittszuschlag fr Vorjahr');
INSERT INTO gifi (accno,description) VALUES ('0221000', 'Kapitalertragssteuer');
INSERT INTO gifi (accno,description) VALUES ('0221300', 'Anrechb.Solidarittszusch.a.Zinsabs');
INSERT INTO gifi (accno,description) VALUES ('0221500', 'Zinsabschlagsteuer');
INSERT INTO gifi (accno,description) VALUES ('0221800', 'Anrechb.Solidari.zuschlag a.Zinsabs');
INSERT INTO gifi (accno,description) VALUES ('0228000', 'Stnachzahl.Vorj.v.Einkomm u.Ertrag');
INSERT INTO gifi (accno,description) VALUES ('0228200', 'Sterstat.Vorj.Steuer v.Eink.u.Ertrag');
INSERT INTO gifi (accno,description) VALUES ('0228400', 'Ertr.a.d.Aufl.v.Rcks.f.St.v.Ein.Er');
INSERT INTO gifi (accno,description) VALUES ('0228500', 'Steuernachzahlung Vorj.f.sons.Steue');
INSERT INTO gifi (accno,description) VALUES ('0228700', 'Steuererstattung Vorj.f.sons.Steuer');
INSERT INTO gifi (accno,description) VALUES ('0228900', 'Ertrge a.d.Aufl.v. Rck.f.sons.Ste');
INSERT INTO gifi (accno,description) VALUES ('0230000', 'Sonstige Aufwendungen');
INSERT INTO gifi (accno,description) VALUES ('0231000', 'Anlagenabgnge - bei Buchverlust');
INSERT INTO gifi (accno,description) VALUES ('0231500', 'Anlagenabgnge-Buchgewinn');
INSERT INTO gifi (accno,description) VALUES ('0232000', 'Verluste Abgang Gegenst.d.Anlagever');
INSERT INTO gifi (accno,description) VALUES ('0232500', 'Verlust a.d.Abg.v.Gegens.d.Umlaufve');
INSERT INTO gifi (accno,description) VALUES ('0234000', 'Einstellungen Sopo m.Rckanlageant.');
INSERT INTO gifi (accno,description) VALUES ('0234500', 'Einstellungen Sopo m.R.(Sonderafa)');
INSERT INTO gifi (accno,description) VALUES ('0237500', 'Grundsteuer');
INSERT INTO gifi (accno,description) VALUES ('0240000', 'Forderungsverlust-bliche Hhe');
INSERT INTO gifi (accno,description) VALUES ('0241000', 'Einstellungen Sopo m.Rckl.(7g )');
INSERT INTO gifi (accno,description) VALUES ('0243000', 'Forderungsverluste-unblich  hoch');
INSERT INTO gifi (accno,description) VALUES ('0245000', 'Einstell.i.d.Pauschalwertbe.z.Forde');
INSERT INTO gifi (accno,description) VALUES ('0245100', 'Einstell.i.d.Einzelwertb.z.Forderun');
INSERT INTO gifi (accno,description) VALUES ('0249000', 'Aufwendung aus Verlustbernahme');
INSERT INTO gifi (accno,description) VALUES ('0249200', 'Abgef.Gewinn aufgr.e.Gewinngemeinsc');
INSERT INTO gifi (accno,description) VALUES ('0249300', 'Abgef.Gewinnant.an stille Gesellsch');
INSERT INTO gifi (accno,description) VALUES ('0249500', 'Einst.Kapitalrckl.n.Vorschr.vere.K');
INSERT INTO gifi (accno,description) VALUES ('0249600', 'Einstellungen in die gesetzl.Rckla');
INSERT INTO gifi (accno,description) VALUES ('0250000', 'Auerordentliche Ertrge');
INSERT INTO gifi (accno,description) VALUES ('0251000', 'Betriebsfremde Ertrge n.auerorden');
INSERT INTO gifi (accno,description) VALUES ('0252000', 'Periodenfremde Ertrge nicht auero');
INSERT INTO gifi (accno,description) VALUES ('0260000', 'Ertrge aus Beteiligten');
INSERT INTO gifi (accno,description) VALUES ('0261700', 'Gewinn a.Anteila.nicht stbef.Kapita');
INSERT INTO gifi (accno,description) VALUES ('0261900', 'Ertrge a.Beteil.a.verb.Untrnehmer');
INSERT INTO gifi (accno,description) VALUES ('0262000', 'Ertrge a.anderen Wertp u.Ausl.Fina');
INSERT INTO gifi (accno,description) VALUES ('0265000', 'Sonstige Zinsen und hnliche Ertrge');
INSERT INTO gifi (accno,description) VALUES ('0265700', 'Zinsertrge-betriebliche Steuern');
INSERT INTO gifi (accno,description) VALUES ('0265800', 'Zinsertrge-Krperschaftssteuer');
INSERT INTO gifi (accno,description) VALUES ('0265900', 'Sons.Zinsen u.hl.Ertr.a.verb.Unter');
INSERT INTO gifi (accno,description) VALUES ('0266000', 'Ertrge aus Kursdifferenzen');
INSERT INTO gifi (accno,description) VALUES ('0266500', 'Ertrge a.d.Whrungumst.a.d. Euro');
INSERT INTO gifi (accno,description) VALUES ('0267000', 'Diskonertrge');
INSERT INTO gifi (accno,description) VALUES ('0270000', 'Sonstige Ertrge');
INSERT INTO gifi (accno,description) VALUES ('0270500', 'Sons.Ertrge betrieb. u. regelmig');
INSERT INTO gifi (accno,description) VALUES ('0271000', 'Ertrag a.d.Zuschreib.d.Anlagevermg');
INSERT INTO gifi (accno,description) VALUES ('0271500', 'Ertr.a.Zuschreib.d.Umlaufvermgens');
INSERT INTO gifi (accno,description) VALUES ('0272000', 'Ertr.a.d.Abgang v.Gegens.d.Anlageve');
INSERT INTO gifi (accno,description) VALUES ('0272500', 'Ertr.a.d.Abg.v.Gegenst.d.Umlaufverm');
INSERT INTO gifi (accno,description) VALUES ('0273000', 'Ertr.a.Herab.d.Pauschal.z.Forderung');
INSERT INTO gifi (accno,description) VALUES ('0273100', 'Ertr.a.Herab.d.Einzelw.z.Forderunge');
INSERT INTO gifi (accno,description) VALUES ('0273200', 'Ertr. aus abgeschriebenen Forderung');
INSERT INTO gifi (accno,description) VALUES ('0273500', 'Ertr.a.d.Auflsung v.Rckstellungen');
INSERT INTO gifi (accno,description) VALUES ('0273600', 'Ertr.a.d.steuerl.niedrig.Bewertung');
INSERT INTO gifi (accno,description) VALUES ('0273700', 'Ertr.a.d..Aufl.v.Sonderp.m.Rcklage');
INSERT INTO gifi (accno,description) VALUES ('0273800', 'Ertr.a.d.Aufl.v.Sopo.m.Rcklageant.');
INSERT INTO gifi (accno,description) VALUES ('0273900', 'Ertrge Aufl. Sopo m.R.(Ansparafa)');
INSERT INTO gifi (accno,description) VALUES ('0274000', 'Ertrge Auflsung Sopo (stfreie R)');
INSERT INTO gifi (accno,description) VALUES ('0274100', 'Ertr.a.d.Aufl.v.Sonderp.m.Rcklagen');
INSERT INTO gifi (accno,description) VALUES ('0274200', 'Versicherungsentschdigungen');
INSERT INTO gifi (accno,description) VALUES ('0274300', 'Investitionszuschsse-steuerpflicht');
INSERT INTO gifi (accno,description) VALUES ('0274400', 'Investitionszulage-steuerfrei');
INSERT INTO gifi (accno,description) VALUES ('0274500', 'Ertrge aus Kapitalherabsetzung');
INSERT INTO gifi (accno,description) VALUES ('0279000', 'Ertrge aus Verlustbernahme');
INSERT INTO gifi (accno,description) VALUES ('0279200', 'Erhalt.Gewinne aufgr.e.Gewinngemein');
INSERT INTO gifi (accno,description) VALUES ('0279400', 'Erhalt.Gewinn aufgr.e.GAV-TeilGAV');
INSERT INTO gifi (accno,description) VALUES ('0279500', 'Entnahme aus der Kapitalrcklage');
INSERT INTO gifi (accno,description) VALUES ('0279600', 'Entnahme a.d. gesetzlichen Rcklage');
INSERT INTO gifi (accno,description) VALUES ('0286000', 'Gewinnvortrag nach Verwendung');
INSERT INTO gifi (accno,description) VALUES ('0286800', 'Verlustvortrag nach Verwendung');
INSERT INTO gifi (accno,description) VALUES ('0286900', 'Vortrag auf neue Rechnungen');
INSERT INTO gifi (accno,description) VALUES ('0287000', 'Vorabausschttung');
INSERT INTO gifi (accno,description) VALUES ('0289200', 'Verrechnete kalkulatorische Zinsen');
INSERT INTO gifi (accno,description) VALUES ('0289300', 'Verrechnete kalkulatorische AfA');
INSERT INTO gifi (accno,description) VALUES ('0299000', 'Aufwendung/Ertrge Umrechnungsdiff');
INSERT INTO gifi (accno,description) VALUES ('0300000', 'Roh,-Hilfs,-und Betriebsstoffe');
INSERT INTO gifi (accno,description) VALUES ('0309000', 'Energiestoffe (Fertigung)');
INSERT INTO gifi (accno,description) VALUES ('0310000', 'Fremdleistungen');
INSERT INTO gifi (accno,description) VALUES ('0315000', 'Leist.v.auslnd.Untern.(0-Regelung)');
INSERT INTO gifi (accno,description) VALUES ('0320000', 'Wareneingang');
INSERT INTO gifi (accno,description) VALUES ('0330000', 'Wareneingang 7% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0340000', 'Wareneingang 16% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0342000', 'Innergemein.Erwerb 7% VorSt u. Ust');
INSERT INTO gifi (accno,description) VALUES ('0342500', 'Innergem.Erwerb 16% VorSt u. Ust');
INSERT INTO gifi (accno,description) VALUES ('0355000', 'Steuerfreier innergem.Erwerb');
INSERT INTO gifi (accno,description) VALUES ('0360000', 'Nicht abziehbare Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0370000', 'Nachlsse');
INSERT INTO gifi (accno,description) VALUES ('0371000', 'Nachlsse 7% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0372000', 'Nachlsse 16% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0373000', 'Erhaltene Skonti');
INSERT INTO gifi (accno,description) VALUES ('0373100', 'Erhaltene Skonti 7% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0373500', 'Erhaltene Skonti 16% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0374000', 'Erhaltene Boni');
INSERT INTO gifi (accno,description) VALUES ('0375000', 'Erhaltene Boni 7% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0376000', 'Erhaltene Boni 16% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0377000', 'Erhaltene Rabatte');
INSERT INTO gifi (accno,description) VALUES ('0378000', 'Erhaltene Rabatte 7% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0379000', 'Erhaltene Rabatte 16% Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0380000', 'Anschaffungsnebenkosten');
INSERT INTO gifi (accno,description) VALUES ('0383000', 'Leergut');
INSERT INTO gifi (accno,description) VALUES ('0385000', 'Zlle und Einfuhrabgaben');
INSERT INTO gifi (accno,description) VALUES ('0396000', 'Bestandsver.Roh-,Hilfs-.Betriebs.');
INSERT INTO gifi (accno,description) VALUES ('0397000', 'Bestand Roh-,Hilfs-,u.Betriebsstoff');
INSERT INTO gifi (accno,description) VALUES ('0398000', 'Bestand Waren');
INSERT INTO gifi (accno,description) VALUES ('0399000', 'Verrechnete Stoffkosten');
INSERT INTO gifi (accno,description) VALUES ('0400000', 'Material-und Stoffverbrauch');
INSERT INTO gifi (accno,description) VALUES ('0410000', 'Lhne und Gehlter');
INSERT INTO gifi (accno,description) VALUES ('0412400', 'Geschftsfhr.gehlter GmbH-Gesell.');
INSERT INTO gifi (accno,description) VALUES ('0412500', 'Ehegattengehalt');
INSERT INTO gifi (accno,description) VALUES ('0412600', 'Tantiemen');
INSERT INTO gifi (accno,description) VALUES ('0412700', 'Geschftsfhrergehlter');
INSERT INTO gifi (accno,description) VALUES ('0412800', 'Vergtung a.angestellte Mitunterneh');
INSERT INTO gifi (accno,description) VALUES ('0413000', 'Gesetzlich soziale Aufwendungen');
INSERT INTO gifi (accno,description) VALUES ('0413700', 'Gesetz.sozi.Aufw.f.Mitunternehmen');
INSERT INTO gifi (accno,description) VALUES ('0413800', 'Beitrge zur Berufsgenossenschaftr');
INSERT INTO gifi (accno,description) VALUES ('0414500', 'Freiwillige sozi.Aufw.lohnsteuerfr.');
INSERT INTO gifi (accno,description) VALUES ('0414900', 'Pauschale Lohnsteuera.sons.Bezge');
INSERT INTO gifi (accno,description) VALUES ('0415000', 'Krankengeldzuschsse');
INSERT INTO gifi (accno,description) VALUES ('0416000', 'Versorgungskasse');
INSERT INTO gifi (accno,description) VALUES ('0416500', 'Aufwendung f.Altersversorgung');
INSERT INTO gifi (accno,description) VALUES ('0417000', 'Vermgenswirksame Leistungen');
INSERT INTO gifi (accno,description) VALUES ('0417500', 'Fahrtkostenerst.Wohnung/Arbeitsstt');
INSERT INTO gifi (accno,description) VALUES ('0419000', 'Aushilfslhne');
INSERT INTO gifi (accno,description) VALUES ('0419900', 'Lohnsteuer fr Aushilfe');
INSERT INTO gifi (accno,description) VALUES ('0420000', 'Raumkosten');
INSERT INTO gifi (accno,description) VALUES ('0421000', 'Miete');
INSERT INTO gifi (accno,description) VALUES ('0422000', 'Pacht');
INSERT INTO gifi (accno,description) VALUES ('0423000', 'Heizung');
INSERT INTO gifi (accno,description) VALUES ('0424000', 'Gas,Strom, Wasser');
INSERT INTO gifi (accno,description) VALUES ('0425000', 'Reinigung');
INSERT INTO gifi (accno,description) VALUES ('0426000', 'Instandhaltung betrieb.Rume');
INSERT INTO gifi (accno,description) VALUES ('0427000', 'Abgaben f.betrieb.genutz.Grundstck');
INSERT INTO gifi (accno,description) VALUES ('0428000', 'Sonstige Raumkosten');
INSERT INTO gifi (accno,description) VALUES ('0430000', 'Nicht abziehbare Vorsteuer');
INSERT INTO gifi (accno,description) VALUES ('0430100', 'Nicht abziehbare Vorsteuer 7%');
INSERT INTO gifi (accno,description) VALUES ('0430500', 'Nicht abziehbare Vorsteuer 16%');
INSERT INTO gifi (accno,description) VALUES ('0432000', 'Gewerbesteuer');
INSERT INTO gifi (accno,description) VALUES ('0434000', 'Sonstige Betriebssteuern');
INSERT INTO gifi (accno,description) VALUES ('0435000', 'Verbrauchssteuer');
INSERT INTO gifi (accno,description) VALUES ('0435500', 'kosteuer');
INSERT INTO gifi (accno,description) VALUES ('0436000', 'Versicherungen');
INSERT INTO gifi (accno,description) VALUES ('0437000', 'Nettopr.f.Rckd.knf.Versorgungsle');
INSERT INTO gifi (accno,description) VALUES ('0438000', 'Beitrge');
INSERT INTO gifi (accno,description) VALUES ('0439000', 'Sonstige Abgaben');
INSERT INTO gifi (accno,description) VALUES ('0439600', 'Steuerl.abzugs.Versp.u.Zwangsgelde');
INSERT INTO gifi (accno,description) VALUES ('0450000', 'Fahrzugkosten');
INSERT INTO gifi (accno,description) VALUES ('0451000', 'Kfz-Steuer');
INSERT INTO gifi (accno,description) VALUES ('0452000', 'Kfz-Versicherungen');
INSERT INTO gifi (accno,description) VALUES ('0453000', 'Laufende Kfz-Betriebskosten');
INSERT INTO gifi (accno,description) VALUES ('0454000', 'Kfz-Reparaturen');
INSERT INTO gifi (accno,description) VALUES ('0455000', 'Garagenmiete');
INSERT INTO gifi (accno,description) VALUES ('0457000', 'Fremdfahrzeuge');
INSERT INTO gifi (accno,description) VALUES ('0458000', 'Sonstige Kfz-Kosten');
INSERT INTO gifi (accno,description) VALUES ('0460000', 'Werbe-und Reisekosten');
INSERT INTO gifi (accno,description) VALUES ('0461000', 'Werbekosten');
INSERT INTO gifi (accno,description) VALUES ('0463000', 'Geschenke bis 75 DM');
INSERT INTO gifi (accno,description) VALUES ('0463500', 'Geschenke bis 75 DM');
INSERT INTO gifi (accno,description) VALUES ('0463800', 'Geschenke ausschliel.betrieb.genut');
INSERT INTO gifi (accno,description) VALUES ('0464000', 'Reprsentationskosten');
INSERT INTO gifi (accno,description) VALUES ('0465000', 'Bewirtungskosten');
INSERT INTO gifi (accno,description) VALUES ('0465300', 'Aufmerksamkeiten');
INSERT INTO gifi (accno,description) VALUES ('0465400', 'Nicht abzugsfhige Bewirtungskosten');
INSERT INTO gifi (accno,description) VALUES ('0465500', 'Nicht abzugsfhige Betriebsausgaben');
INSERT INTO gifi (accno,description) VALUES ('0466000', 'Reisekosten Arbeitnehmer');
INSERT INTO gifi (accno,description) VALUES ('0466300', 'Reisekosten Arbeitn.m.Vorsteuerabzu');
INSERT INTO gifi (accno,description) VALUES ('0466400', 'Reisekosten Arbeitn.Verpflegungmehr');
INSERT INTO gifi (accno,description) VALUES ('0466600', 'Reisekosten Arbeitn.bernachtungsau');
INSERT INTO gifi (accno,description) VALUES ('0466800', 'Kilometerentgelderstattung Arbeitne');
INSERT INTO gifi (accno,description) VALUES ('0467000', 'Reisekosten Unternehmer');
INSERT INTO gifi (accno,description) VALUES ('0467400', 'Reisekosten Untern.Verpflegungsmehr');
INSERT INTO gifi (accno,description) VALUES ('0467600', 'Reisekosten Untern.bernachtungsauf');
INSERT INTO gifi (accno,description) VALUES ('0467800', 'Kilometererstattungsgeld Unternehme');
INSERT INTO gifi (accno,description) VALUES ('0470000', 'Kosten der Warenabgabe');
INSERT INTO gifi (accno,description) VALUES ('0471000', 'Verpackungsmaterial');
INSERT INTO gifi (accno,description) VALUES ('0473000', 'Ausgangsfracht');
INSERT INTO gifi (accno,description) VALUES ('0475000', 'Transportversicherung');
INSERT INTO gifi (accno,description) VALUES ('0476000', 'Verkaufsprovision');
INSERT INTO gifi (accno,description) VALUES ('0478000', 'Fremdarbeiten');
INSERT INTO gifi (accno,description) VALUES ('0479000', 'Aufwand fr Gewhrleistungen');
INSERT INTO gifi (accno,description) VALUES ('0480900', 'Sonstige Reparaturen u.Instandhalt.');
INSERT INTO gifi (accno,description) VALUES ('0481000', 'Mietleasing');
INSERT INTO gifi (accno,description) VALUES ('0481500', 'Kaufleasing');
INSERT INTO gifi (accno,description) VALUES ('0482000', 'AfA a.Aufw.f.d.Inga.u.Erw.Geschfts');
INSERT INTO gifi (accno,description) VALUES ('0482100', 'AfA a.Aufw.f.d.Whrungsumst.a.Euro');
INSERT INTO gifi (accno,description) VALUES ('0482200', 'Abschreibungen a.immat.Vermgensgeg');
INSERT INTO gifi (accno,description) VALUES ('0482400', 'Abschreibung a.d.Geschft-o.Firmenw');
INSERT INTO gifi (accno,description) VALUES ('0482600', 'Auerplan.AfA a.immat.Vermgensgeg.');
INSERT INTO gifi (accno,description) VALUES ('0483000', 'Abschreibungen auf Sachanlagen');
INSERT INTO gifi (accno,description) VALUES ('0484000', 'Auerplanmig Abschr.a.Sachanlagen');
INSERT INTO gifi (accno,description) VALUES ('0485000', 'Abschr.a.Sachanl.steuerl.Sondervors');
INSERT INTO gifi (accno,description) VALUES ('0485500', 'Sofortabschreibung GWG');
INSERT INTO gifi (accno,description) VALUES ('0486000', 'Abschreibungen auf aktivierte GWG');
INSERT INTO gifi (accno,description) VALUES ('0487000', 'Abschreibungen auf Finanzanlagen');
INSERT INTO gifi (accno,description) VALUES ('0487500', 'Abschr.a.Wertp.d.Umlaufvermgens');
INSERT INTO gifi (accno,description) VALUES ('0490000', 'Sonstige betriebliche Aufwendungen');
INSERT INTO gifi (accno,description) VALUES ('0490500', 'Sons.Aufw.betriebl. und regelmig');
INSERT INTO gifi (accno,description) VALUES ('0490900', 'Fremdleistungen');
INSERT INTO gifi (accno,description) VALUES ('0491000', 'Porto');
INSERT INTO gifi (accno,description) VALUES ('0492000', 'Telefon');
INSERT INTO gifi (accno,description) VALUES ('0492500', 'Telefax');
INSERT INTO gifi (accno,description) VALUES ('0493000', 'Brobedarf');
INSERT INTO gifi (accno,description) VALUES ('0494000', 'Zeitschriften, Bcher');
INSERT INTO gifi (accno,description) VALUES ('0494500', 'Fortbildungskosten');
INSERT INTO gifi (accno,description) VALUES ('0494600', 'Freiwillige Sozialleistungen');
INSERT INTO gifi (accno,description) VALUES ('0495000', 'Rechts- und Beratungskosten');
INSERT INTO gifi (accno,description) VALUES ('0495500', 'Buchfhrungskosten');
INSERT INTO gifi (accno,description) VALUES ('0495700', 'Abschlu- und Prfungskosten');
INSERT INTO gifi (accno,description) VALUES ('0496000', 'Mieten fr Einrichtungen');
INSERT INTO gifi (accno,description) VALUES ('0497000', 'Nebenkosten des Geldverkehrs');
INSERT INTO gifi (accno,description) VALUES ('0498000', 'Betriebsbedarf');
INSERT INTO gifi (accno,description) VALUES ('0498500', 'Werkzeuge und Kleingerte');
INSERT INTO gifi (accno,description) VALUES ('0498600', 'Sonstige Aufwendungen (Ausbuchung)');
INSERT INTO gifi (accno,description) VALUES ('0499000', 'Kalkulatorischer Unternehmerlohn');
INSERT INTO gifi (accno,description) VALUES ('0499200', 'Kalkulatorische Zinsen');
INSERT INTO gifi (accno,description) VALUES ('0499300', 'Kalkulatorische Aschreibungen');
INSERT INTO gifi (accno,description) VALUES ('0499600', 'Herstellungskosten');
INSERT INTO gifi (accno,description) VALUES ('0499700', 'Verwaltungskosten');
INSERT INTO gifi (accno,description) VALUES ('0499800', 'Vertriebskosten');
INSERT INTO gifi (accno,description) VALUES ('0700000', 'Unfertige Erzeu.unfert.Leistungen');
INSERT INTO gifi (accno,description) VALUES ('0705000', 'Unfertige Erzeugnisse');
INSERT INTO gifi (accno,description) VALUES ('0708000', 'Unfertige Leistungen');
INSERT INTO gifi (accno,description) VALUES ('0709000', 'In Ausfhrung befindl. Bauauftrge');
INSERT INTO gifi (accno,description) VALUES ('0709500', 'In Arbeit befindliche Auftrge');
INSERT INTO gifi (accno,description) VALUES ('0710000', 'Fertige Erzeugnisse und Waren');
INSERT INTO gifi (accno,description) VALUES ('0711000', 'Fertige Erzeugnisse (Bestand)');
INSERT INTO gifi (accno,description) VALUES ('0714000', 'Waren (Bestand)');
INSERT INTO gifi (accno,description) VALUES ('0810000', 'Steuerfreie Umstze 4Nr.8ff UstG');
INSERT INTO gifi (accno,description) VALUES ('0811000', 'Sonstige steuerfreie Umstze Inland');
INSERT INTO gifi (accno,description) VALUES ('0812000', 'Steuerfreie Umstze 4Nr.1a UstG');
INSERT INTO gifi (accno,description) VALUES ('0812500', 'Steuerfrei innergem. Lieferungen');
INSERT INTO gifi (accno,description) VALUES ('0813000', 'Liefe.d.1.Abnehm.innergem.Dreiecksg');
INSERT INTO gifi (accno,description) VALUES ('0815000', 'Sonstige steuerfreie Umstze');
INSERT INTO gifi (accno,description) VALUES ('0819000', 'Sonstige Erlse (Ausbuchung 0%)');
INSERT INTO gifi (accno,description) VALUES ('0819100', 'Sonstige Erlse (Ausbuchung 16%)');
INSERT INTO gifi (accno,description) VALUES ('0819200', 'Sonstige Erlse (Ausbuchung 7%)');
INSERT INTO gifi (accno,description) VALUES ('0820000', 'Erlse');
INSERT INTO gifi (accno,description) VALUES ('0830000', 'Erlse 7%USt');
INSERT INTO gifi (accno,description) VALUES ('0831000', 'Erlse Inland stpfl. EG-Lieferung7%');
INSERT INTO gifi (accno,description) VALUES ('0831500', 'Erls Inland stpfl.EG-Lieferung 16%');
INSERT INTO gifi (accno,description) VALUES ('0833900', 'Erl.EG-Land stpfl.so.Leist.(0-Regl)');
INSERT INTO gifi (accno,description) VALUES ('0840000', 'Erlse 16% USt.');
INSERT INTO gifi (accno,description) VALUES ('0850000', 'Provisionserlse');
INSERT INTO gifi (accno,description) VALUES ('0852000', 'Erlse Abfallverwertung');
INSERT INTO gifi (accno,description) VALUES ('0854000', 'Erls Leergut');
INSERT INTO gifi (accno,description) VALUES ('0859000', 'Verrechnete sons. Sachbezge');
INSERT INTO gifi (accno,description) VALUES ('0859100', 'Sachbezge 7% Ust (Waren)');
INSERT INTO gifi (accno,description) VALUES ('0859500', 'Sachbezge 16% Ust (Waren)');
INSERT INTO gifi (accno,description) VALUES ('0860000', 'Sonstige Erlse betriebl.u.regelm');
INSERT INTO gifi (accno,description) VALUES ('0861000', 'Verrechnete sonstige Sachbezge');
INSERT INTO gifi (accno,description) VALUES ('0861100', 'Verr.sons.Sachbezge 16%USt(Kfz-Ge)');
INSERT INTO gifi (accno,description) VALUES ('0861400', 'Verrechnete sons.Sachbezge o. USt');
INSERT INTO gifi (accno,description) VALUES ('0862500', 'Sons. Erlse betriebl.u.reg.steuerf');
INSERT INTO gifi (accno,description) VALUES ('0865000', 'Erlse Zinsen und Diskotspesen');
INSERT INTO gifi (accno,description) VALUES ('0870000', 'Erlsschmlerungen');
INSERT INTO gifi (accno,description) VALUES ('0871000', 'Erlsschmlerung 7% USt.');
INSERT INTO gifi (accno,description) VALUES ('0872000', 'Erlsschmlerung 16% USt.');
INSERT INTO gifi (accno,description) VALUES ('0872400', 'Erlsschmler.a.stfrei.IG Lieferung');
INSERT INTO gifi (accno,description) VALUES ('0872500', 'Erlsschm.Inl.stpfl.EG-Lief. 7%USt');
INSERT INTO gifi (accno,description) VALUES ('0872600', 'Erlsschm.Inl.stpfl.EG-Lief.16%USt');
INSERT INTO gifi (accno,description) VALUES ('0872700', 'Erlsschm.and.EG Land stpfl.Liefer');
INSERT INTO gifi (accno,description) VALUES ('0873000', 'Gewhrte Skonti');
INSERT INTO gifi (accno,description) VALUES ('0873100', 'Gewhrte Skonti 7% USt');
INSERT INTO gifi (accno,description) VALUES ('0873500', 'Gewhrte Skonti 16% USt.');
INSERT INTO gifi (accno,description) VALUES ('0874000', 'Gewhrte Boni');
INSERT INTO gifi (accno,description) VALUES ('0875000', 'Gewhrte Boni 7% USt.');
INSERT INTO gifi (accno,description) VALUES ('0876000', 'Gewhrte Boni 16% USt.');
INSERT INTO gifi (accno,description) VALUES ('0877000', 'Gewhrte Rabatte');
INSERT INTO gifi (accno,description) VALUES ('0878000', 'Gewhrte Rabatte 7% USt.');
INSERT INTO gifi (accno,description) VALUES ('0879000', 'Gewhrte Rabatte 16% Ust.');
INSERT INTO gifi (accno,description) VALUES ('0880000', 'Erlse aus Anlagenverkufen');
INSERT INTO gifi (accno,description) VALUES ('0880100', 'Erlse aus Anlagenverkufen 16%USt.');
INSERT INTO gifi (accno,description) VALUES ('0882000', 'Erlse aus Anlageverkufen 16%Ust');
INSERT INTO gifi (accno,description) VALUES ('0882900', 'Erl.a.Anlagenverk.bei Buchgewinn');
INSERT INTO gifi (accno,description) VALUES ('0890000', 'Unentgeldliche Wertabgaben');
INSERT INTO gifi (accno,description) VALUES ('0890500', 'Entnahme v. Gegenst.o.USt.');
INSERT INTO gifi (accno,description) VALUES ('0891000', 'Entnahme auerhalb d.Untern.16%USt.');
INSERT INTO gifi (accno,description) VALUES ('0891500', 'Entnah.d.U.Zweckauerh.d.Untn 7%USt');
INSERT INTO gifi (accno,description) VALUES ('0891800', 'Entn.d.Untern.auerh.d.Untern.o.USt');
INSERT INTO gifi (accno,description) VALUES ('0892000', 'Verw.v.Gegens.auerh.Untern.16%USt.');
INSERT INTO gifi (accno,description) VALUES ('0892500', 'Unentgeldl.Erbring.sons.Leis.16%USt');
INSERT INTO gifi (accno,description) VALUES ('0893200', 'Unentgelt.Erbring.sons.Leist. 7%Ust');
INSERT INTO gifi (accno,description) VALUES ('0893500', 'Unentgeltl.Zuwend.v.Gegens. 16% Ust');
INSERT INTO gifi (accno,description) VALUES ('0893900', 'Unentgeldl.Zuw.v.Gegens.ohne Ust');
INSERT INTO gifi (accno,description) VALUES ('0894000', 'Unentgeltl.Zuw.v Waren 16% Ust');
INSERT INTO gifi (accno,description) VALUES ('0894500', 'Unentgeltl.Zuw.von Waren 7% Ust');
INSERT INTO gifi (accno,description) VALUES ('0895000', 'Nicht steuerbare Umstze');
INSERT INTO gifi (accno,description) VALUES ('0895500', 'Umsatzsteuervergtungen');
INSERT INTO gifi (accno,description) VALUES ('0896000', 'Bestandsvernderung-unfertige Erzeu');
INSERT INTO gifi (accno,description) VALUES ('0897000', 'Bestandsvernderung-unfertige Leist');
INSERT INTO gifi (accno,description) VALUES ('0897500', 'Bestandsver.i.Ausf.befi.Bauauftr');
INSERT INTO gifi (accno,description) VALUES ('0897700', 'Bestandsver.i.Arbeit befindl.Auftr');
INSERT INTO gifi (accno,description) VALUES ('0898000', 'Bestandsver.fertige Erzeugnisse');
INSERT INTO gifi (accno,description) VALUES ('0899000', 'Andere aktivierte Eigenleistungen');
INSERT INTO gifi (accno,description) VALUES ('0900000', 'Saldenvertrge,Sachkonten');
INSERT INTO gifi (accno,description) VALUES ('0900800', 'Saldenvertrge,Debitoren');
INSERT INTO gifi (accno,description) VALUES ('0900900', 'Saldenvertrge,Kreditoren');
INSERT INTO gifi (accno,description) VALUES ('0906000', 'Offene Posten aus 1990');
INSERT INTO gifi (accno,description) VALUES ('0906900', 'Offene Posten aus 1999');
INSERT INTO gifi (accno,description) VALUES ('0907000', 'Offene Posten aus 2000');
INSERT INTO gifi (accno,description) VALUES ('0909000', 'Summenvortragskonto');
INSERT INTO gifi (accno,description) VALUES ('0922000', 'Gezeichnetes kapital in DM');
INSERT INTO gifi (accno,description) VALUES ('0922100', 'Gezeichnetes Kapital in Euro');
INSERT INTO gifi (accno,description) VALUES ('0923000', 'Baukostenzuschsse');
INSERT INTO gifi (accno,description) VALUES ('0923200', 'Investitionszulagen');
INSERT INTO gifi (accno,description) VALUES ('0923400', 'Investitionszuschsse');
INSERT INTO gifi (accno,description) VALUES ('0924500', 'Forde.a.Anlageverk.sons.Vermgensge');
INSERT INTO gifi (accno,description) VALUES ('0925000', 'Eigenkapitalersetzende Ges''terdarl.');
INSERT INTO gifi (accno,description) VALUES ('0926000', 'Kurzfristige Rckstellung');
INSERT INTO gifi (accno,description) VALUES ('0926200', 'Mittelfristige Rckstellung');
INSERT INTO gifi (accno,description) VALUES ('0926400', 'Langfristige Rckstellungen');
INSERT INTO gifi (accno,description) VALUES ('0928000', 'Bemessungsgrundlage IG Erwerb 16%');
INSERT INTO gifi (accno,description) VALUES ('0928100', 'Gegenkonto Bmsgrl. IG Erwerb 16%');
INSERT INTO gifi (accno,description) VALUES ('0928200', 'Bemessungsgrundlage IG Erwerb 7%');
INSERT INTO gifi (accno,description) VALUES ('0928400', 'Gegenkonto Bmsgrl. IG Erwerb 7%');
INSERT INTO gifi (accno,description) VALUES ('0988100', 'Verrechnungskonto Abgang');
INSERT INTO gifi (accno,description) VALUES ('0988200', 'Verrechnungskonto erh. Anzahlungen');
INSERT INTO gifi (accno,description) VALUES ('0988210', 'Verrechnungskto Anzahlungen netto');
INSERT INTO gifi (accno,description) VALUES ('0988220', 'Verrechnungskto.Anzahlungen brutto');
INSERT INTO gifi (accno,description) VALUES ('0988300', 'Verrechnungskonto gel.Anzahlungen');
INSERT INTO gifi (accno,description) VALUES ('0988400', 'Statistisches Konto Konzern AfA');
INSERT INTO gifi (accno,description) VALUES ('0988500', 'Statistisches Konto kalkulator.AfA');
INSERT INTO gifi (accno,description) VALUES ('0988600', 'Statistisches Konto auerplanm AfA');
INSERT INTO gifi (accno,description) VALUES ('0988700', 'Statistisches Konto AfA (Konzern)');
INSERT INTO gifi (accno,description) VALUES ('0988800', 'Statistisches Konto Sonderafa');
INSERT INTO gifi (accno,description) VALUES ('0988900', 'Statistisches Konto AfA (SBil)');
INSERT INTO gifi (accno,description) VALUES ('0989800', 'Statistisches Konto AfA (Kalkul.)');
INSERT INTO gifi (accno,description) VALUES ('0989900', 'Statistisches Konto AfA');
INSERT INTO gifi (accno,description) VALUES ('0999999', 'Fehlerauffangkonto');
